## How to Contribute

The project is run on Github, in the [typical](http://producingoss.com) free software way. 
We'd love to accept your patches and contributions to this project. 
There are just a few small guidelines you need to follow.

Our production vision and high level requirements are explained in the [BRIEF.md](BRIEF.md).

We use Github's Issue Tracker to report and track bugs, map out future improvements, set priorities and assign people to them.
We only assign an issue to someone when they are going to work on that issue soon.
We tag all issues with a priority tag, P0 for "urgent" through P5 for "someday-maybe"

If you find a bug or have an idea, please create a new issue and we'll be happy to work with you on it!

## Google CLA

Contributions to this project must be accompanied by a Contributor License Agreement. 
You (or your employer) retain the copyright to your contribution; 
this simply gives us permission to use and redistribute your contributions as part of the project.
Head over to <https://cla.developers.google.com/> to see your current agreements on file or to sign a new one.

You generally only need to submit a CLA once, so if you've already submitted one (even if it was for a different project), you probably don't need to do it again.

After your contribution is included, you will be listed in [CONTRIBUTORS.txt](CONTRIBUTORS.txt) and/or [AUTHORS.txt](AUTHORS.txt):
`CONTRIBUTORS.txt` is the official list of people who can contribute (and typically have contributed) code to this repository, while the `AUTHORS.txt` file lists the copyright holders.

## Code reviews

All submissions, including submissions by project members, require review. 
We use GitHub pull requests for this purpose. 
Consult [GitHub Help](https://help.github.com/articles/about-pull-requests/) for more information on using pull requests.

## Community Guidelines

This project follows [Google's Open Source Community Guidelines](https://opensource.google.com/conduct/)

We also have a [CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md)
